Module registry

Module registry 

Error registry for compatibility with deferred error handling APIs.

Structs

ErrorRegistry
A synchronized, type-checked registry for a single error value.

Statics

ERROR_REGISTRY
Global error registry for recording the most recent deferred error.